# Nomenclature

* `ExperimentBatch` is a set of `Experiments`.
* Single `Experiment` consists from a number of `Series`. 
* All `Series` that given `Experiment` consists of are run for single test case.
* Single `Series` is a single solver run and its outputs.
